﻿@* Remove this section if you are using bundling *@
@Section Scripts
    <script src="~/Scripts/jquery.validate.min.js"></script>
    <script src="~/Scripts/jquery.validate.unobtrusive.min.js"></script>
End Section

@Code
    ' Handle user request to swap theme
    If Not Request.QueryString("Theme") Is Nothing Then
        Dim swapTo As String = Request.QueryString("Theme")
        InitializeApplication.SwapTheme(swapTo)
    End If

    ' set page properties
    Layout = Helpers.SetTheme().ToString
    PageData("Title") = "Log in"

    ' Initialize general page variables
    Dim email As String = ""
    Dim password As String = ""
    Dim rememberMe As Boolean = False
    Dim DisplayName As WebSecurity = Nothing

    Dim returnUrl As String = Request.QueryString("ReturnUrl")
    If returnUrl.IsEmpty() Then
        ' Some external login providers always require a return URL value
        returnUrl = Href("~/")
    End If

    ' Setup validation
    Validation.RequireField("email", "You must specify an email address.")
    Validation.RequireField("password", "You must specify a password.")
    Validation.Add("password",
        Validator.StringLength(
            maxLength:=Int32.MaxValue,
            minLength:=6,
            errorMessage:="Password must be at least 6 characters"))

    ' If this is a POST request, validate and process data
    If IsPost Then
        AntiForgery.Validate()
        ' is this an external login request?
        Dim provider As String = Request.Form("provider")
        If Not Provider.IsEmpty() Then
            OAuthWebSecurity.RequestAuthentication(Provider, Href("~/Account/RegisterService", New With { .ReturnUrl = returnUrl }))
            Return
        ElseIf Validation.IsValid() Then
            email = Request.Form("email")
            password = Request.Form("password")
            rememberMe = Request.Form("rememberMe").AsBool()

            If WebSecurity.UserExists(email) AndAlso WebSecurity.GetPasswordFailuresSinceLastSuccess(email) > 4 AndAlso WebSecurity.GetLastPasswordFailureDate(email).AddSeconds(60) > DateTime.UtcNow Then
                Response.Redirect("~/Account/AccountLockedOut")
                Return
            End If

            ' Attempt to log in using provided credentials
            If WebSecurity.Login(email, password, rememberMe) Then
                Context.RedirectLocal(returnUrl)
                Return
            Else
                ModelState.AddFormError("The user name or password provided is incorrect.")
            End If
        End If
    End If
End Code

<hgroup class="title">
    <h1>@PageData("Title").</h1>
</hgroup>

<section id="loginForm">
    <h2>Use a local account to log in.</h2>
    <div id="formcontainer">
        <div class="forms">
            <form method="post">
                @AntiForgery.GetHtml()
                @* If one or more validation errors exist, show an error *@
                @Html.ValidationSummary("Log in was unsuccessful. Please correct the errors and try again.", excludeFieldErrors:=True, htmlAttributes:=Nothing)
                <fieldset>
                    <legend>Log in to Your Account</legend>
                    <div class="email">
                        <div class="form_lbl">
                            <label for="email" @If Not ModelState.IsValidField("email") Then @<text> class="error-label" </text>  End If>Email address</label>
                        </div>
                        <div class="form_field">
                            <input type="text" id="email" name="email" value="@email" @Validation.For("email") />
                            @* Write any user name validation errors to the page *@
                            @Html.ValidationMessage("email")
                        </div>
                    </div>
                    <div class="password">
                        <div class="form_lbl">
                            <label for="password" @If Not ModelState.IsValidField("password") Then @<text> class="error-label" </text>       End If>Password</label>
                        </div>
                        <div class="form_field">
                            <input type="password" id="password" name="password" @Validation.For("password") />
                            @* Write any password validation errors to the page *@
                            @Html.ValidationMessage("password")
                        </div>
                    </div>
                    <div class="remember-me">
                        <div class="form_lbl"><label class="checkbox" for="rememberMe">Remember me?</label></div>
                        <div class="form_field">
                            <input type="checkbox" id="rememberMe" name="rememberMe" value="true" checked="@rememberMe" />
                        </div>
                    </div>
                    <div class="form_btn"><input type="submit" value="Log in" class="button" /></div>
                </fieldset>
            </form>
        </div>
    </div>
    <p>
        <a href="~/Account/Register">Don't have a Account?</a>
        <a href="~/Account/ForgotPassword">Did you forget your password?</a>
    </p>
</section>

<section class="social" id="socialLoginForm">
    <h2>Use another service to log in.</h2>
    @RenderPage("~/Account/_ExternalLoginsList.vbhtml")
</section>
